abacusai.prediction_metric_version — AbacusAI documentation

# `abacusai.prediction_metric_version`

## Module Contents

### Classes

`PredictionMetricVersion` | A Prediction Metric version for a Prediction Metric job description.

class abacusai.prediction_metric_version.PredictionMetricVersion(client, createdAt=None, error=None, featureGroupVersion=None, predictionMetricCompletedAt=None, predictionMetricConfig=None, predictionMetricId=None, predictionMetricStartedAt=None, predictionMetricVersion=None, status=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A Prediction Metric version for a Prediction Metric job description.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - createdAt (str) – Date and time when this prediction metric version was created.

    - error (str) – Relevant error if the status of this job version is FAILED.

    - featureGroupVersion (str) – The feature group version used as input to this prediction metric.

    - predictionMetricCompletedAt (str) – The time and date computations were completed for this job version.

    - predictionMetricConfig (dict) – Specification for the prediction metric used to run this job.

    - predictionMetricId (str) – The unique identifier of the prediction metric this is a version of.

    - predictionMetricStartedAt (str) – The time and date computations were started for this job version.

    - predictionMetricVersion (str) – The unique identifier of this prediction metric version.

    - status (str) – The current status of the computations for this job version.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  wait_for_prediction_metric_version(timeout=1200)

    A waiting call until the prediction metric version is ready.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Get the lifecycle status of this version.

    Returns:

      An enum value of the lifecycle status of this version.

    Return type:

      str